# Release 1.2.2
This is a minor release that adds a feature for sending unsolicited messages.

## New Features
 - Added function for sending unsolicited messages to a device. See [here](https://github.com/ISISComputingGroup/lewis/commit/08a335a8b11661478c97fd88e3e7d6bb9fcea866).
